# dial-basic-nodes
Basic nodes for DL tasks, used by the Dial app.

## Documentation

This project's documentation lives at [readthedocs.io](https://dial-basic-nodes.readthedocs.io)

## License

All code is provided under the __GPL-3.0__ license. See [LICENSE](LICENSE) for more details.

## Authors

* **David Afonso (davafons)**: [Github](https://github.com/davafons) [Twitter](https://twitter.com/davafons)
